@@ -4,7 +4,6 @@ def get_input(event):
     try:
         trigger_source = None
         input_params = None
-
         if 'httpMethod' in event and event['httpMethod'] == 'POST':
             trigger_source = 'api-gateway'
             if 'body' in event:
@@ -12,9 +11,13 @@ def get_input(event):
         elif 'Records' in event and isinstance(event['Records'], list):
             trigger_source = 'aws-service-kafka'
             for record in event['Records']:
+                print(record)
                 if 'kafka' in record:
-                    kafka_record = json.loads(record['kafka']['data'])
+                    kafka_record = record['kafka']['data']
+                    print('\n\n')
+                    print(kafka_record)
                     input_params = kafka_record['message']
+                    print(input_params)
         elif 'source' in event and event['source'] == 'cli':
             trigger_source = 'cli'
             input_params = event
